import os
from dotenv import load_dotenv

load_dotenv()

from openai import OpenAI

client = OpenAI()

import langwatch.prompt

import chainlit as cl

langwatch.setup()


@cl.on_message
@langwatch.trace()
async def main(message: cl.Message):
    langwatch.get_current_trace().autotrack_openai_calls(client)
    langwatch.get_current_trace().update(
        metadata={"labels": ["openai", "prompt-versioning"]},
    )

    msg = cl.Message(
        content="",
    )

    ## Gets the prompt and autobuilds it with the provided variables
    ## Returns an object that can be passed into the OpenAI client
    ## directly:
    # Raw prompt {model: 'gpt-4o-mini', messages: [{ role: 'system', content: 'The user is {{user_name}} and their email is {{user_email}}' }, { role: 'user', content: '{{input}}' }]}
    # Autobuilt prompt { model: 'gpt-4o-mini', messages: [{ role: 'system', content: 'The user is John Doe and their email is john.doe@example.com' }, { role: 'user', content: 'I like to eat pizza' }]}
    # Public documentation example prompt
    prompt_id = os.getenv("LANGWATCH_PROMPT_ID", "prompt_TrYXZLsiTJkn9N6PiZiae")
    prompt = await langwatch.prompt.async_get_prompt(prompt_id)
    print(prompt.raw_config())
    messages = prompt.format_messages(
        user_name="John Doe",
        user_email="john.doe@example.com",
        input="I like to eat pizza",
    )

    completion = client.chat.completions.create(
        model=prompt.model.split("openai/")[1],
        messages=messages,
        stream=True,
    )

    for part in completion:
        if token := part.choices[0].delta.content or "":
            await msg.stream_token(token)

    await msg.update()



from strands import Agent
from strands.models.litellm import LiteLLMModel
import os
import langwatch

from openinference.instrumentation.litellm import LiteLLMInstrumentor

from typing import cast
from dotenv import load_dotenv

load_dotenv()

import chainlit as cl
import litellm
from litellm import CustomStreamWrapper
from litellm.types.utils import StreamingChoices
from strands.telemetry.tracer import get_tracer

tracer = get_tracer(
    service_name="strands-bot",
    otlp_endpoint=f"{os.environ.get('LANGWATCH_ENDPOINT', 'https://app.langwatch.ai')}/api/otel/v1/traces",
    otlp_headers={"Authorization": "Bearer " + os.environ["LANGWATCH_API_KEY"]},
    enable_console_export=True,  # Helpful for development
)

class KiteAgent:
    def __init__(self):
        langwatch.setup(instrumentors=[LiteLLMInstrumentor()])

        self.model = LiteLLMModel(
            client_args={
                "api_key": os.getenv("OPENAI_API_KEY"),
            },
            model_id="openai/gpt-4.1-nano",
        )
        self.agent = Agent(
            model=self.model,
            tools=[],
        )

    def run(self, prompt: str):
        return self.agent(prompt)


@cl.on_message
# @langwatch.trace()
async def main(message: cl.Message):
    # langwatch.get_current_trace().autotrack_litellm_calls(litellm)

    msg = cl.Message(
        content="",
    )

    agent = KiteAgent()
    response = agent.run(message.content)

    await msg.stream_token(str(response))

    await msg.update()



from langwatch.evaluation.evaluation import Evaluation
from .evaluation import Evaluation


def init(name: str) -> Evaluation:
    evaluation = Evaluation(name)
    evaluation.init()
    return evaluation
